**Example 1: 游戏服务器会话队列**



Input: 

```
tccli gse DeleteGameServerSessionQueue --cli-unfold-argument  \
    --Name queue2
```

Output: 
```
{
    "Response": {
        "RequestId": "3118ddfd-1fb0-4560-adf4-1da1216sdsdfedb"
    }
}
```

